@@ -1,19 +1,17 @@
-from __future__ import absolute_import, unicode_literals
-
-import warnings
-
 from django.template.loader import render_to_string
 
 from debug_toolbar import settings as dt_settings
 from debug_toolbar.utils import get_name_from_obj
 
 
-class Panel(object):
+class Panel:
     """
     Base class for panels.
     """
-    def __init__(self, toolbar):
+
+    def __init__(self, toolbar, get_response):
         self.toolbar = toolbar
+        self.get_response = get_response
 
     # Private panel properties
 
@@ -24,21 +22,22 @@ class Panel(object):
     @property
     def enabled(self):
         # Check to see if settings has a default value for it
-        disabled_panels = dt_settings.get_config()['DISABLE_PANELS']
+        disabled_panels = dt_settings.get_config()["DISABLE_PANELS"]
         panel_path = get_name_from_obj(self)
         # Some panels such as the SQLPanel and TemplatesPanel exist in a
         # panel module, but can be disabled without panel in the path.
         # For that reason, replace .panel. in the path and check for that
         # value in the disabled panels as well.
         disable_panel = (
-            panel_path in disabled_panels or
-            panel_path.replace('.panel.', '.') in disabled_panels)
+            panel_path in disabled_panels
+            or panel_path.replace(".panel.", ".") in disabled_panels
+        )
         if disable_panel:
-            default = 'off'
+            default = "off"
         else:
-            default = 'on'
+            default = "on"
         # The user's cookies should override the default value
-        return self.toolbar.request.COOKIES.get('djdt' + self.panel_id, default) == 'on'
+        return self.toolbar.request.COOKIES.get("djdt" + self.panel_id, default) == "on"
 
     # Titles and content
 
@@ -54,7 +53,7 @@ class Panel(object):
         """
         Subtitle shown in the side bar. Defaults to the empty string.
         """
-        return ''
+        return ""
 
     @property
     def has_content(self):
@@ -127,8 +126,7 @@ class Panel(object):
         This is the opposite of :meth:`enable_instrumentation`.
 
         Unless the toolbar or this panel is disabled, this method will be
-        called late in :class:`DebugToolbarMiddleware.process_response`. It
-        should be idempotent.
+        called late in the middleware. It should be idempotent.
         """
 
     # Store and retrieve stats (shared between panels for no good reason)
@@ -147,44 +145,40 @@ class Panel(object):
         """
         return self.toolbar.stats.get(self.panel_id, {})
 
+    def record_server_timing(self, key, title, value):
+        """
+        Store data gathered by the panel. ``stats`` is a :class:`dict`.
+
+        Each call to ``record_stats`` updates the statistics dictionary.
+        """
+        data = {key: {"title": title, "value": value}}
+        self.toolbar.server_timing_stats.setdefault(self.panel_id, {}).update(data)
+
+    def get_server_timing_stats(self):
+        """
+        Access data stored by the panel. Returns a :class:`dict`.
+        """
+        return self.toolbar.server_timing_stats.get(self.panel_id, {})
+
     # Standard middleware methods
 
     def process_request(self, request):
         """
-        Like process_request in Django's middleware.
+        Like __call__ in Django's middleware.
 
         Write panel logic related to the request there. Save data with
         :meth:`record_stats`.
-        """
 
-    def process_view(self, request, view_func, view_args, view_kwargs):
-        """
-        Like process_view in Django's middleware.
-
-        Write panel logic related to the view there. Save data with
-        :meth:`record_stats`.
-        """
-
-    def process_response(self, request, response):
-        """
-        Like process_response in Django's middleware. This is similar to
-        :meth:`generate_stats <debug_toolbar.panels.Panel.generate_stats>`,
-        but will be executed on every request. It should be used when either
-        the logic needs to be executed on every request or it needs to change
-        the response entirely, such as :class:`RedirectsPanel`.
-
-        Write panel logic related to the response there. Post-process data
-        gathered while the view executed. Save data with :meth:`record_stats`.
-
-        Return a response to overwrite the existing response.
+        Return the existing response or overwrite it.
         """
+        return self.get_response(request)
 
     def generate_stats(self, request, response):
         """
-        Similar to :meth:`process_response
-        <debug_toolbar.panels.Panel.process_response>`,
-        but may not be executed on every request. This will only be called if
-        the toolbar will be inserted into the request.
+        Called after :meth:`process_request
+        <debug_toolbar.panels.Panel.process_request>`, but may not be executed
+        on every request. This will only be called if the toolbar will be
+        inserted into the request.
 
         Write panel logic related to the response there. Post-process data
         gathered while the view executed. Save data with :meth:`record_stats`.
@@ -192,10 +186,12 @@ class Panel(object):
         Does not return a value.
         """
 
+    def generate_server_timing(self, request, response):
+        """
+        Similar to :meth:`generate_stats
+        <debug_toolbar.panels.Panel.generate_stats>`,
 
-# Backward-compatibility for 1.0, remove in 2.0.
-class DebugPanel(Panel):
+        Generate stats for Server Timing https://w3c.github.io/server-timing/
 
-    def __init__(self, *args, **kwargs):
-        warnings.warn("DebugPanel was renamed to Panel.", DeprecationWarning)
-        super(DebugPanel, self).__init__(*args, **kwargs)
+        Does not return a value.
+        """
