@@ -2,8 +2,6 @@
 The main DebugToolbar class that loads and renders the Toolbar.
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import uuid
 from collections import OrderedDict
 
@@ -17,16 +15,23 @@ from django.utils.module_loading import import_string
 from debug_toolbar import settings as dt_settings
 
 
-class DebugToolbar(object):
-
-    def __init__(self, request):
+class DebugToolbar:
+    def __init__(self, request, get_response):
         self.request = request
         self.config = dt_settings.get_config().copy()
+        panels = []
+        for panel_class in reversed(self.get_panel_classes()):
+            panel = panel_class(self, get_response)
+            panels.append(panel)
+            if panel.enabled:
+                get_response = panel.process_request
+        self.process_request = get_response
         self._panels = OrderedDict()
-        for panel_class in self.get_panel_classes():
-            panel_instance = panel_class(self)
-            self._panels[panel_instance.panel_id] = panel_instance
+        while panels:
+            panel = panels.pop()
+            self._panels[panel.panel_id] = panel
         self.stats = {}
+        self.server_timing_stats = {}
         self.store_id = None
 
     # Manage panels
@@ -60,14 +65,15 @@ class DebugToolbar(object):
         if not self.should_render_panels():
             self.store()
         try:
-            context = {'toolbar': self}
-            return render_to_string('debug_toolbar/base.html', context)
+            context = {"toolbar": self}
+            return render_to_string("debug_toolbar/base.html", context)
         except TemplateSyntaxError:
-            if not apps.is_installed('django.contrib.staticfiles'):
+            if not apps.is_installed("django.contrib.staticfiles"):
                 raise ImproperlyConfigured(
                     "The debug toolbar requires the staticfiles contrib app. "
                     "Add 'django.contrib.staticfiles' to INSTALLED_APPS and "
-                    "define STATIC_URL in your settings.")
+                    "define STATIC_URL in your settings."
+                )
             else:
                 raise
 
@@ -76,16 +82,16 @@ class DebugToolbar(object):
     _store = OrderedDict()
 
     def should_render_panels(self):
-        render_panels = self.config['RENDER_PANELS']
+        render_panels = self.config["RENDER_PANELS"]
         if render_panels is None:
-            render_panels = self.request.META['wsgi.multiprocess']
+            render_panels = self.request.META["wsgi.multiprocess"]
         return render_panels
 
     def store(self):
         self.store_id = uuid.uuid4().hex
         cls = type(self)
         cls._store[self.store_id] = self
-        for _ in range(len(cls._store) - self.config['RESULTS_CACHE_SIZE']):
+        for _ in range(len(cls._store) - self.config["RESULTS_CACHE_SIZE"]):
             try:
                 # collections.OrderedDict
                 cls._store.popitem(last=False)
@@ -107,8 +113,7 @@ class DebugToolbar(object):
         if cls._panel_classes is None:
             # Load panels in a temporary variable for thread safety.
             panel_classes = [
-                import_string(panel_path)
-                for panel_path in dt_settings.get_panels()
+                import_string(panel_path) for panel_path in dt_settings.get_panels()
             ]
             cls._panel_classes = panel_classes
         return cls._panel_classes
@@ -119,10 +124,11 @@ class DebugToolbar(object):
     def get_urls(cls):
         if cls._urlpatterns is None:
             from . import views
+
             # Load URLs in a temporary variable for thread safety.
             # Global URLs
             urlpatterns = [
-                url(r'^render_panel/$', views.render_panel, name='render_panel'),
+                url(r"^render_panel/$", views.render_panel, name="render_panel")
             ]
             # Per-panel URLs
             for panel_class in cls.get_panel_classes():
@@ -131,5 +137,5 @@ class DebugToolbar(object):
         return cls._urlpatterns
 
 
-app_name = 'djdt'
+app_name = "djdt"
 urlpatterns = DebugToolbar.get_urls()
