@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import inspect
 import os.path
 import re
@@ -10,13 +8,10 @@ from itertools import chain
 import django
 from django.core.exceptions import ImproperlyConfigured
 from django.template import Node
-from django.utils import six
-from django.utils.encoding import force_text
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
 
 from debug_toolbar import settings as dt_settings
-from debug_toolbar.compat import linebreak_iter
 
 try:
     import threading
@@ -32,18 +27,17 @@ def get_module_path(module_name):
     try:
         module = import_module(module_name)
     except ImportError as e:
-        raise ImproperlyConfigured(
-            'Error importing HIDE_IN_STACKTRACES: %s' % (e,))
+        raise ImproperlyConfigured("Error importing HIDE_IN_STACKTRACES: {}".format(e))
     else:
         source_path = inspect.getsourcefile(module)
-        if source_path.endswith('__init__.py'):
+        if source_path.endswith("__init__.py"):
             source_path = os.path.dirname(source_path)
         return os.path.realpath(source_path)
 
 
 hidden_paths = [
     get_module_path(module_name)
-    for module_name in dt_settings.get_config()['HIDE_IN_STACKTRACES']
+    for module_name in dt_settings.get_config()["HIDE_IN_STACKTRACES"]
 ]
 
 
@@ -64,7 +58,7 @@ def tidy_stacktrace(stack):
     for frame, path, line_no, func_name, text in (f[:5] for f in stack):
         if omit_path(os.path.realpath(path)):
             continue
-        text = (''.join(force_text(t) for t in text)).strip() if text else ''
+        text = "".join(text).strip() if text else ""
         trace.append((path, line_no, func_name, text))
     return trace
 
@@ -73,18 +67,20 @@ def render_stacktrace(trace):
     stacktrace = []
     for frame in trace:
         params = (escape(v) for v in chain(frame[0].rsplit(os.path.sep, 1), frame[1:]))
-        params_dict = {six.text_type(idx): v for idx, v in enumerate(params)}
+        params_dict = {str(idx): v for idx, v in enumerate(params)}
         try:
-            stacktrace.append('<span class="djdt-path">%(0)s/</span>'
-                              '<span class="djdt-file">%(1)s</span>'
-                              ' in <span class="djdt-func">%(3)s</span>'
-                              '(<span class="djdt-lineno">%(2)s</span>)\n'
-                              '  <span class="djdt-code">%(4)s</span>'
-                              % params_dict)
+            stacktrace.append(
+                '<span class="djdt-path">%(0)s/</span>'
+                '<span class="djdt-file">%(1)s</span>'
+                ' in <span class="djdt-func">%(3)s</span>'
+                '(<span class="djdt-lineno">%(2)s</span>)\n'
+                '  <span class="djdt-code">%(4)s</span>' % params_dict
+            )
         except KeyError:
-            # This frame doesn't have the expected format, so skip it and move on to the next one
+            # This frame doesn't have the expected format, so skip it and move
+            # on to the next one
             continue
-    return mark_safe('\n'.join(stacktrace))
+    return mark_safe("\n".join(stacktrace))
 
 
 def get_template_info():
@@ -102,9 +98,9 @@ def get_template_info():
                 # If the method in the stack trace is this one
                 # then break from the loop as it's being check recursively.
                 break
-            elif cur_frame.f_code.co_name == 'render':
-                node = cur_frame.f_locals['self']
-                context = cur_frame.f_locals['context']
+            elif cur_frame.f_code.co_name == "render":
+                node = cur_frame.f_locals["self"]
+                context = cur_frame.f_locals["context"]
                 if isinstance(node, Node):
                     template_info = get_template_context(node, context)
                     break
@@ -116,73 +112,39 @@ def get_template_info():
 
 
 def get_template_context(node, context, context_lines=3):
-    source = getattr(node, 'source', None)
-    # In Django 1.9 template Node does not have source property, Origin does
-    # not reload method, so we extract contextual information from exception
-    # info.
-    if source:
-        line, source_lines, name = get_template_source_from_source(source)
-    else:
-        line, source_lines, name = get_template_source_from_exception_info(
-            node, context)
+    line, source_lines, name = get_template_source_from_exception_info(node, context)
     debug_context = []
     start = max(1, line - context_lines)
     end = line + 1 + context_lines
 
     for line_num, content in source_lines:
         if start <= line_num <= end:
-            debug_context.append({
-                'num': line_num,
-                'content': content,
-                'highlight': (line_num == line),
-            })
+            debug_context.append(
+                {"num": line_num, "content": content, "highlight": (line_num == line)}
+            )
 
-    return {
-        'name': name,
-        'context': debug_context,
-    }
-
-
-def get_template_source_from_source(source):
-    line = 0
-    upto = 0
-    source_lines = []
-    # before = during = after = ""
-
-    origin, (start, end) = source
-    template_source = origin.reload()
-
-    for num, next in enumerate(linebreak_iter(template_source)):
-        if start >= upto and end <= next:
-            line = num
-            # before = template_source[upto:start]
-            # during = template_source[start:end]
-            # after = template_source[end:next]
-        source_lines.append((num, template_source[upto:next]))
-        upto = next
-    return line, source_lines, origin.name
+    return {"name": name, "context": debug_context}
 
 
 def get_template_source_from_exception_info(node, context):
-    exception_info = context.template.get_exception_info(
-        Exception('DDT'), node.token)
-    line = exception_info['line']
-    source_lines = exception_info['source_lines']
-    name = exception_info['name']
+    exception_info = context.template.get_exception_info(Exception("DDT"), node.token)
+    line = exception_info["line"]
+    source_lines = exception_info["source_lines"]
+    name = exception_info["name"]
     return line, source_lines, name
 
 
 def get_name_from_obj(obj):
-    if hasattr(obj, '__name__'):
+    if hasattr(obj, "__name__"):
         name = obj.__name__
-    elif hasattr(obj, '__class__') and hasattr(obj.__class__, '__name__'):
+    elif hasattr(obj, "__class__") and hasattr(obj.__class__, "__name__"):
         name = obj.__class__.__name__
     else:
-        name = '<unknown>'
+        name = "<unknown>"
 
-    if hasattr(obj, '__module__'):
+    if hasattr(obj, "__module__"):
         module = obj.__module__
-        name = '%s.%s' % (module, name)
+        name = "{}.{}".format(module, name)
 
     return name
 
@@ -206,37 +168,37 @@ def getframeinfo(frame, context=1):
     else:
         lineno = frame.f_lineno
     if not inspect.isframe(frame):
-        raise TypeError('arg is not a frame or traceback object')
+        raise TypeError("arg is not a frame or traceback object")
 
     filename = inspect.getsourcefile(frame) or inspect.getfile(frame)
     if context > 0:
         start = lineno - 1 - context // 2
         try:
             lines, lnum = inspect.findsource(frame)
-        except Exception:   # findsource raises platform-dependant exceptions
+        except Exception:  # findsource raises platform-dependant exceptions
             first_lines = lines = index = None
         else:
             start = max(start, 1)
             start = max(0, min(start, len(lines) - context))
             first_lines = lines[:2]
-            lines = lines[start:(start + context)]
+            lines = lines[start : (start + context)]
             index = lineno - 1 - start
     else:
         first_lines = lines = index = None
 
     # Code taken from Django's ExceptionReporter._get_lines_from_file
     if first_lines and isinstance(first_lines[0], bytes):
-        encoding = 'ascii'
+        encoding = "ascii"
         for line in first_lines[:2]:
             # File coding may be specified. Match pattern from PEP-263
             # (https://www.python.org/dev/peps/pep-0263/)
-            match = re.search(br'coding[:=]\s*([-\w.]+)', line)
+            match = re.search(br"coding[:=]\s*([-\w.]+)", line)
             if match:
-                encoding = match.group(1).decode('ascii')
+                encoding = match.group(1).decode("ascii")
                 break
-        lines = [line.decode(encoding, 'replace') for line in lines]
+        lines = [line.decode(encoding, "replace") for line in lines]
 
-    if hasattr(inspect, 'Traceback'):
+    if hasattr(inspect, "Traceback"):
         return inspect.Traceback(filename, lineno, frame.f_code.co_name, lines, index)
     else:
         return (filename, lineno, frame.f_code.co_name, lines, index)
@@ -259,12 +221,13 @@ def get_stack(context=1):
     return framelist
 
 
-class ThreadCollector(object):
+class ThreadCollector:
     def __init__(self):
         if threading is None:
             raise NotImplementedError(
                 "threading module is not available, "
-                "this panel cannot be used without it")
+                "this panel cannot be used without it"
+            )
         self.collections = {}  # a dictionary that maps threads to collections
 
     def get_collection(self, thread=None):
