@@ -1,8 +1,6 @@
-from __future__ import absolute_import, unicode_literals
-
 from django.http import HttpResponse
 from django.utils.html import escape
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from debug_toolbar.decorators import require_show_toolbar
 from debug_toolbar.toolbar import DebugToolbar
@@ -11,12 +9,14 @@ from debug_toolbar.toolbar import DebugToolbar
 @require_show_toolbar
 def render_panel(request):
     """Render the contents of a panel"""
-    toolbar = DebugToolbar.fetch(request.GET['store_id'])
+    toolbar = DebugToolbar.fetch(request.GET["store_id"])
     if toolbar is None:
-        content = _("Data for this panel isn't available anymore. "
-                    "Please reload the page and retry.")
+        content = _(
+            "Data for this panel isn't available anymore. "
+            "Please reload the page and retry."
+        )
         content = "<p>%s</p>" % escape(content)
     else:
-        panel = toolbar.get_panel_by_id(request.GET['panel_id'])
+        panel = toolbar.get_panel_by_id(request.GET["panel_id"])
         content = panel.content
     return HttpResponse(content)
